"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("..");
// Mock implementation of AuthIntegration
const mockIntegration = {
    signIn: () => __awaiter(void 0, void 0, void 0, function* () { return ({ success: true }); }),
    signOut: () => __awaiter(void 0, void 0, void 0, function* () { return ({ success: true }); }),
    signUp: () => __awaiter(void 0, void 0, void 0, function* () { return ({ success: true }); }),
    lockAccount: () => __awaiter(void 0, void 0, void 0, function* () { return ({ success: true }); }),
    resetPassword: () => __awaiter(void 0, void 0, void 0, function* () { return ({ success: true }); }),
    confirmSignUp: () => __awaiter(void 0, void 0, void 0, function* () { return ({ success: true }); }),
    resendSignUp: () => __awaiter(void 0, void 0, void 0, function* () { return ({ success: true }); }),
    forgotPassword: () => __awaiter(void 0, void 0, void 0, function* () { return ({ success: true }); }),
    forgotPasswordConfirmationCode: () => __awaiter(void 0, void 0, void 0, function* () { return ({ success: true }); }),
};
// Test createAuthProvider function
describe('createAuthProvider', () => {
    let authProvider;
    beforeEach(() => {
        authProvider = (0, __1.createAuthProvider)(mockIntegration);
    });
    it('should return a valid AuthProvider object', () => {
        expect(authProvider).toBeDefined();
        expect(authProvider.signIn).toBeDefined();
        expect(authProvider.signOut).toBeDefined();
        expect(authProvider.signUp).toBeDefined();
        expect(authProvider.lockAccount).toBeDefined();
        expect(authProvider.resetPassword).toBeDefined();
        expect(authProvider.confirmSignUp).toBeDefined();
        expect(authProvider.resendSignUp).toBeDefined();
        expect(authProvider.forgotPassword).toBeDefined();
        expect(authProvider.forgotPasswordConfirmationCode).toBeDefined();
    });
    it('should call integration.signIn when signIn is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.signIn('username', 'password');
        expect(result.success).toBe(true);
    }));
    it('should call integration.signOut when signOut is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.signOut();
        expect(result.success).toBe(true);
    }));
    it('should return a valid AuthProvider object', () => {
        const integration = {
            signIn: jest.fn(),
            signOut: jest.fn(),
            signUp: jest.fn(),
            lockAccount: jest.fn(),
            resetPassword: jest.fn(),
            confirmSignUp: jest.fn(),
            resendSignUp: jest.fn(),
            forgotPassword: jest.fn(),
            forgotPasswordConfirmationCode: jest.fn(),
        };
        const authProvider = (0, __1.createAuthProvider)(integration);
        expect(authProvider).toBeDefined();
        expect(authProvider.signIn).toBeDefined();
        expect(authProvider.signOut).toBeDefined();
        expect(authProvider.signUp).toBeDefined();
        expect(authProvider.lockAccount).toBeDefined();
        expect(authProvider.resetPassword).toBeDefined();
        expect(authProvider.confirmSignUp).toBeDefined();
        expect(authProvider.resendSignUp).toBeDefined();
        expect(authProvider.forgotPassword).toBeDefined();
        expect(authProvider.forgotPasswordConfirmationCode).toBeDefined();
    });
    it('should call integration.signIn when signIn is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.signIn('username', 'password');
        expect(result.success).toBe(true);
    }));
    it('should call integration.signOut when signOut is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.signOut();
        expect(result.success).toBe(true);
    }));
    it('should call integration.signUp when signUp is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.signUp('username', 'password', 'email');
        expect(result.success).toBe(true);
    }));
    it('should call integration.lockAccount when lockAccount is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.lockAccount('username');
        expect(result.success).toBe(true);
    }));
    it('should call integration.resetPassword when resetPassword is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.resetPassword('username');
        expect(result.success).toBe(true);
    }));
    it('should call integration.confirmSignUp when confirmSignUp is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.confirmSignUp('username', 'code');
        expect(result.success).toBe(true);
    }));
    it('should call integration.resendSignUp when resendSignUp is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.resendSignUp('username');
        expect(result.success).toBe(true);
    }));
    it('should call integration.forgotPassword when forgotPassword is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.forgotPassword('username');
        expect(result.success).toBe(true);
    }));
    it('should call integration.forgotPasswordConfirmationCode when forgotPasswordConfirmationCode is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.forgotPasswordConfirmationCode('username', 'code', 'newPassword');
        expect(result.success).toBe(true);
    }));
    it('should call integration.signIn when signIn is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const integration = {
            signIn: jest.fn(() => Promise.resolve({ success: true })),
            signOut: function () {
                throw new Error('Function not implemented.');
            },
            signUp: function (username, password, email) {
                throw new Error('Function not implemented.');
            },
            lockAccount: function (username) {
                throw new Error('Function not implemented.');
            },
            resetPassword: function (username) {
                throw new Error('Function not implemented.');
            },
            confirmSignUp: function (username, code) {
                throw new Error('Function not implemented.');
            },
            resendSignUp: function (username) {
                throw new Error('Function not implemented.');
            },
            forgotPassword: function (username) {
                throw new Error('Function not implemented.');
            },
            forgotPasswordConfirmationCode: function (username, code, newPassword) {
                throw new Error('Function not implemented.');
            }
        };
        const authProvider = (0, __1.createAuthProvider)(integration);
        const result = yield authProvider.signIn('username', 'password');
        expect(integration.signIn).toHaveBeenCalledWith('username', 'password');
        expect(result).resolves;
    }));
    it('should call integration.signOut when signOut is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const integration = {
            signOut: jest.fn(() => Promise.resolve({ success: true })),
            signIn: function (username, password) {
                throw new Error('Function not implemented.');
            },
            signUp: function (username, password, email) {
                throw new Error('Function not implemented.');
            },
            lockAccount: function (username) {
                throw new Error('Function not implemented.');
            },
            resetPassword: function (username) {
                throw new Error('Function not implemented.');
            },
            confirmSignUp: function (username, code) {
                throw new Error('Function not implemented.');
            },
            resendSignUp: function (username) {
                throw new Error('Function not implemented.');
            },
            forgotPassword: function (username) {
                throw new Error('Function not implemented.');
            },
            forgotPasswordConfirmationCode: function (username, code, newPassword) {
                throw new Error('Function not implemented.');
            }
        };
        const authProvider = (0, __1.createAuthProvider)(integration);
        const result = yield authProvider.signOut();
        expect(integration.signOut).toHaveBeenCalled();
        expect(result).resolves;
    }));
});
